@@ -23,7 +23,7 @@ import chrome from 'ui/chrome';
 import { VisRequestHandlersRegistryProvider as RequestHandlersProvider } from 'ui/registry/vis_request_handlers';
 import { VisResponseHandlersRegistryProvider as ResponseHandlerProvider } from 'ui/registry/vis_response_handlers';
 import { VisTypesRegistryProvider } from 'ui/registry/vis_types';
-import { IndexPatternsProvider } from 'ui/index_patterns';
+import { IndexPatternsProvider } from '../../../data/public';
 import { FilterBarQueryFilterProvider } from 'ui/filter_manager/query_filter';
 import { PersistedState } from 'ui/persisted_state';
 
