@@ -20,7 +20,9 @@
 import { VisFactoryProvider } from 'ui/vis/vis_factory';
 import { i18n } from '@kbn/i18n';
 import { Schemas } from 'ui/vis/editors/default/schemas';
-import pointSeriesTemplate from './editors/point_series.html';
+import { PointSeriesOptions } from './components/options';
+import { getLegendPositions, LegendPositions } from './utils/legend_positions';
+import { palettes } from '@elastic/eui/lib/services';
 
 export default function PointSeriesVisType(Private) {
   const VisFactory = Private(VisFactoryProvider);
@@ -95,16 +97,24 @@ export default function PointSeriesVisType(Private) {
         ],
         addTooltip: true,
         addLegend: true,
-        legendPosition: 'right',
+        legendPosition: LegendPositions.RIGHT,
         times: [],
         addTimeMarker: false,
         labels: {
           show: false,
+        },
+        thresholdLine: {
+          show: false,
+          value: 10,
+          width: 1,
+          style: 'full',
+          color: palettes.euiPaletteColorBlind.colors[9]
         }
       },
     },
     editorConfig: {
       collections: {
+        legendPositions: getLegendPositions(),
         positions: ['top', 'left', 'right', 'bottom'],
         chartTypes: [{
           value: 'line',
@@ -137,7 +147,7 @@ export default function PointSeriesVisType(Private) {
           editor: '<div><vislib-series></vislib-series><vislib-value-axes>' +
           '</vislib-value-axes><vislib-category-axis></vislib-category-axis></div>'
         },
-        { name: 'options', title: 'Panel Settings', editor: pointSeriesTemplate },
+        { name: 'options', title: 'Panel Settings', editor: PointSeriesOptions },
       ],
       schemas: new Schemas([
         {
