@@ -71,7 +71,6 @@ module.factory('SavedDashboard', function (Private) {
       clearSavedIndexPattern: true
     });
 
-
     this.showInRecentlyAccessed = true;
   }
 
@@ -85,10 +84,6 @@ module.factory('SavedDashboard', function (Private) {
     description: 'text',
     panelsJSON: 'text',
     optionsJSON: 'text',
-    // Note: this field is no longer used for dashboards created or saved in version 6.2 onward.  We keep it around
-    // due to BWC, until we can ensure a migration step for all old dashboards saved in an index, as well as
-    // migration steps for importing.  See https://github.com/elastic/kibana/issues/15204 for more info.
-    uiStateJSON: 'text',
     version: 'integer',
     timeRestore: 'boolean',
     timeTo: 'keyword',
@@ -113,5 +108,15 @@ module.factory('SavedDashboard', function (Private) {
     return `/app/kibana#${createDashboardEditUrl(this.id)}`;
   };
 
+  SavedDashboard.prototype.getQuery = function () {
+    return this.searchSource.getOwnField('query') ||
+      { query: '', language: 'kuery' };
+  };
+
+  SavedDashboard.prototype.getFilters = function () {
+    return this.searchSource.getOwnField('filter') || [];
+  };
+
+
   return SavedDashboard;
 });
