@@ -21,21 +21,24 @@ import 'ngreact';
 import { wrapInI18nContext } from 'ui/i18n';
 import { uiModules } from 'ui/modules';
 
-import {
-  DiscoverNoResults,
-} from './no_results';
+import { DiscoverNoResults } from './no_results';
 
-import {
-  DiscoverUnsupportedIndexPattern,
-} from './unsupported_index_pattern';
+import { DiscoverUninitialized } from './uninitialized';
+
+import { DiscoverUnsupportedIndexPattern } from './unsupported_index_pattern';
 
 import './timechart';
 
 const app = uiModules.get('apps/discover', ['react']);
 
-app.directive('discoverNoResults', reactDirective => reactDirective(wrapInI18nContext(DiscoverNoResults)));
+app.directive('discoverNoResults', reactDirective =>
+  reactDirective(wrapInI18nContext(DiscoverNoResults))
+);
 
-app.directive(
-  'discoverUnsupportedIndexPattern',
-  reactDirective => reactDirective(wrapInI18nContext(DiscoverUnsupportedIndexPattern), ['unsupportedType'])
+app.directive('discoverUninitialized', reactDirective =>
+  reactDirective(wrapInI18nContext(DiscoverUninitialized))
+);
+
+app.directive('discoverUnsupportedIndexPattern', reactDirective =>
+  reactDirective(wrapInI18nContext(DiscoverUnsupportedIndexPattern), ['unsupportedType'])
 );
