@@ -207,7 +207,9 @@ uiModules.get('apps/management')
     $scope.migrate = async function () {
       $scope.migration.isMigrating = true;
       await $scope.indexPattern.migrate($scope.migration.newTitle);
-      $scope.migration.isMigrating = false;
+      $scope.$evalAsync(() => {
+        $scope.migration.isMigrating = false;
+      });
     };
 
     $scope.refreshFilters = function () {
@@ -274,7 +276,7 @@ uiModules.get('apps/management')
           }
         }
 
-        Promise.resolve(indexPatterns.delete($scope.indexPattern))
+        Promise.resolve($scope.indexPattern.destroy())
           .then(function () {
             $location.url('/management/kibana/index_patterns');
           })
