@@ -28,7 +28,7 @@ import { render, unmountComponentAtNode } from 'react-dom';
 import { ObjectsTable } from './components/objects_table';
 import { I18nContext } from 'ui/i18n';
 import { get } from 'lodash';
-import { getNewPlatform } from 'ui/new_platform';
+import { npStart } from 'ui/new_platform';
 
 import { getIndexBreadcrumbs } from './breadcrumbs';
 
@@ -40,10 +40,11 @@ function updateObjectsTable($scope, $injector) {
   const $http = $injector.get('$http');
   const kbnUrl = $injector.get('kbnUrl');
   const config = $injector.get('config');
+  const confirmModalPromise = $injector.get('confirmModalPromise');
 
   const savedObjectsClient = Private(SavedObjectsClientProvider);
   const services = savedObjectManagementRegistry.all().map(obj => $injector.get(obj.service));
-  const uiCapabilites = getNewPlatform().start.core.application.capabilities;
+  const uiCapabilites = npStart.core.application.capabilities;
 
   $scope.$$postDigest(() => {
     const node = document.getElementById(REACT_OBJECTS_TABLE_DOM_ELEMENT_ID);
@@ -55,6 +56,7 @@ function updateObjectsTable($scope, $injector) {
       <I18nContext>
         <ObjectsTable
           savedObjectsClient={savedObjectsClient}
+          confirmModalPromise={confirmModalPromise}
           services={services}
           indexPatterns={indexPatterns}
           $http={$http}
