@@ -18,6 +18,7 @@
  */
 
 import _ from 'lodash';
+import { Subscription } from 'rxjs';
 import { i18n } from '@kbn/i18n';
 import '../saved_visualizations/saved_visualizations';
 import './visualization_editor';
@@ -54,7 +55,9 @@ import { showSaveModal } from 'ui/saved_objects/show_saved_object_save_modal';
 import { SavedObjectSaveModal } from 'ui/saved_objects/components/saved_object_save_modal';
 import { getEditBreadcrumbs, getCreateBreadcrumbs } from '../breadcrumbs';
 import { npStart } from 'ui/new_platform';
+import { setup as data } from '../../../../../core_plugins/data/public/legacy';
 
+const { savedQueryService } = data.search.services;
 
 uiRoutes
   .when(VisualizeConstants.CREATE_PATH, {
@@ -106,7 +109,6 @@ uiRoutes
 
 uiModules
   .get('app/visualize', [
-    'kibana/notify',
     'kibana/url'
   ])
   .directive('visualizeApp', function () {
@@ -153,7 +155,8 @@ function VisEditor(
   };
 
   $scope.topNavMenu = [...(capabilities.get().visualize.save ? [{
-    key: i18n.translate('kbn.topNavMenu.saveVisualizationButtonLabel', { defaultMessage: 'save' }),
+    id: 'save',
+    label: i18n.translate('kbn.topNavMenu.saveVisualizationButtonLabel', { defaultMessage: 'save' }),
     description: i18n.translate('kbn.visualize.topNavMenu.saveVisualizationButtonAriaLabel', {
       defaultMessage: 'Save Visualization',
     }),
@@ -206,12 +209,13 @@ function VisEditor(
       showSaveModal(saveModal);
     }
   }] : []), {
-    key: i18n.translate('kbn.topNavMenu.shareVisualizationButtonLabel', { defaultMessage: 'share' }),
+    id: 'share',
+    label: i18n.translate('kbn.topNavMenu.shareVisualizationButtonLabel', { defaultMessage: 'share' }),
     description: i18n.translate('kbn.visualize.topNavMenu.shareVisualizationButtonAriaLabel', {
       defaultMessage: 'Share Visualization',
     }),
     testId: 'shareTopNavButton',
-    run: (menuItem, navController, anchorElement) => {
+    run: (anchorElement) => {
       const hasUnappliedChanges = vis.dirty;
       const hasUnsavedChanges = $appStatus.dirty;
       showShareContextMenu({
@@ -229,7 +233,8 @@ function VisEditor(
       });
     }
   }, {
-    key: i18n.translate('kbn.topNavMenu.openInspectorButtonLabel', { defaultMessage: 'inspect' }),
+    id: 'inspector',
+    label: i18n.translate('kbn.topNavMenu.openInspectorButtonLabel', { defaultMessage: 'inspect' }),
     description: i18n.translate('kbn.visualize.topNavMenu.openInspectorButtonAriaLabel', {
       defaultMessage: 'Open Inspector for visualization',
     }),
@@ -252,7 +257,8 @@ function VisEditor(
       }
     }
   }, {
-    key: i18n.translate('kbn.topNavMenu.refreshButtonLabel', { defaultMessage: 'refresh' }),
+    id: 'refresh',
+    label: i18n.translate('kbn.topNavMenu.refreshButtonLabel', { defaultMessage: 'refresh' }),
     description: i18n.translate('kbn.visualize.topNavMenu.refreshButtonAriaLabel', {
       defaultMessage: 'Refresh',
     }),
@@ -330,6 +336,12 @@ function VisEditor(
     }
   });
 
+  $scope.showSaveQuery = capabilities.get().visualize.saveQuery;
+
+  $scope.$watch(() => capabilities.get().visualize.saveQuery, (newCapability) => {
+    $scope.showSaveQuery = newCapability;
+  });
+
   function init() {
     // export some objects
     $scope.savedVis = savedVis;
@@ -354,10 +366,18 @@ function VisEditor(
 
     $scope.isAddToDashMode = () => addToDashMode;
 
-    $scope.showQueryBar = () => {
+    $scope.showFilterBar = () => {
+      return vis.type.options.showFilterBar;
+    };
+
+    $scope.showQueryInput = () => {
       return vis.type.requiresSearch && vis.type.options.showQueryBar;
     };
 
+    $scope.showQueryBarTimePicker = () => {
+      return vis.type.options.showTimePicker;
+    };
+
     $scope.timeRange = timefilter.getTime();
     $scope.opts = _.pick($scope, 'savedVis', 'isAddToDashMode');
 
@@ -373,33 +393,6 @@ function VisEditor(
 
     $state.replace();
 
-    $scope.$watchMulti([
-      'searchSource.getField("index")',
-      'vis.type.options.showTimePicker',
-      $scope.showQueryBar,
-    ], function ([index, requiresTimePicker, showQueryBar]) {
-      const showTimeFilter = Boolean((!index || index.timeFieldName) && requiresTimePicker);
-
-      if (showQueryBar) {
-        timefilter.disableTimeRangeSelector();
-        timefilter.disableAutoRefreshSelector();
-        $scope.enableQueryBarTimeRangeSelector = true;
-        $scope.showAutoRefreshOnlyInQueryBar = !showTimeFilter;
-      }
-      else if (showTimeFilter) {
-        timefilter.enableTimeRangeSelector();
-        timefilter.enableAutoRefreshSelector();
-        $scope.enableQueryBarTimeRangeSelector = false;
-        $scope.showAutoRefreshOnlyInQueryBar = false;
-      }
-      else {
-        timefilter.disableTimeRangeSelector();
-        timefilter.enableAutoRefreshSelector();
-        $scope.enableQueryBarTimeRangeSelector = false;
-        $scope.showAutoRefreshOnlyInQueryBar = false;
-      }
-    });
-
     const updateTimeRange = () => {
       $scope.timeRange = timefilter.getTime();
       // In case we are running in embedded mode (i.e. we used the visualize loader to embed)
@@ -411,37 +404,43 @@ function VisEditor(
       }
     };
 
-    const updateRefreshInterval = () => {
-      $scope.refreshInterval = timefilter.getRefreshInterval();
-    };
+    const subscriptions = new Subscription();
 
-    $scope.$listenAndDigestAsync(timefilter, 'timeUpdate', updateTimeRange);
-    $scope.$listenAndDigestAsync(timefilter, 'refreshIntervalUpdate', updateRefreshInterval);
-
-    // update the searchSource when filters update
-    const filterUpdateSubscription = subscribeWithScope($scope, queryFilter.getUpdates$(), {
+    subscriptions.add(subscribeWithScope($scope, timefilter.getRefreshIntervalUpdate$(), {
       next: () => {
-        $scope.filters = queryFilter.getFilters();
-        $scope.fetch();
+        $scope.refreshInterval = timefilter.getRefreshInterval();
       }
-    });
+    }));
+    subscriptions.add(subscribeWithScope($scope, timefilter.getTimeUpdate$(), {
+      next: updateTimeRange
+    }));
 
     // update the searchSource when query updates
     $scope.fetch = function () {
       $state.save();
       savedVis.searchSource.setField('query', $state.query);
       savedVis.searchSource.setField('filter', $state.filters);
-      $scope.globalFilters = queryFilter.getGlobalFilters();
       $scope.vis.forceReload();
     };
 
+    // update the searchSource when filters update
+    subscriptions.add(subscribeWithScope($scope, queryFilter.getUpdates$(), {
+      next: () => {
+        $scope.filters = queryFilter.getFilters();
+        $scope.globalFilters = queryFilter.getGlobalFilters();
+      }
+    }));
+    subscriptions.add(subscribeWithScope($scope, queryFilter.getFetches$(), {
+      next: $scope.fetch
+    }));
+
     $scope.$on('$destroy', function () {
       if ($scope._handler) {
         $scope._handler.destroy();
       }
       savedVis.destroy();
       stateMonitor.destroy();
-      filterUpdateSubscription.unsubscribe();
+      subscriptions.unsubscribe();
     });
 
     if (!$scope.chrome.getVisible()) {
@@ -457,9 +456,16 @@ function VisEditor(
   }
 
   $scope.updateQueryAndFetch = function ({ query, dateRange }) {
-    timefilter.setTime(dateRange);
+    const isUpdate = (
+      (query && !_.isEqual(query, $state.query)) ||
+      (dateRange && !_.isEqual(dateRange, $scope.timeRange))
+    );
+
     $state.query = query;
-    $scope.fetch();
+    timefilter.setTime(dateRange);
+
+    // If nothing has changed, trigger the fetch manually, otherwise it will happen as a result of the changes
+    if (!isUpdate) $scope.fetch();
   };
 
   $scope.onRefreshChange = function ({ isPaused, refreshInterval }) {
@@ -469,6 +475,67 @@ function VisEditor(
     });
   };
 
+  $scope.onQuerySaved = savedQuery => {
+    $scope.savedQuery = savedQuery;
+  };
+
+  $scope.onSavedQueryUpdated = savedQuery => {
+    $scope.savedQuery = { ...savedQuery };
+  };
+
+  $scope.onClearSavedQuery = () => {
+    delete $scope.savedQuery;
+    delete $state.savedQuery;
+    $state.query = {
+      query: '',
+      language: localStorage.get('kibana.userQueryLanguage') || config.get('search:queryLanguage')
+    };
+    queryFilter.removeAll();
+    $state.save();
+    $scope.fetch();
+  };
+
+  const updateStateFromSavedQuery = (savedQuery) => {
+    $state.query = savedQuery.attributes.query;
+    queryFilter.setFilters(savedQuery.attributes.filters || []);
+
+    if (savedQuery.attributes.timefilter) {
+      timefilter.setTime({
+        from: savedQuery.attributes.timefilter.from,
+        to: savedQuery.attributes.timefilter.to,
+      });
+      if (savedQuery.attributes.timefilter.refreshInterval) {
+        timefilter.setRefreshInterval(savedQuery.attributes.timefilter.refreshInterval);
+      }
+    }
+
+    $scope.fetch();
+  };
+
+  $scope.$watch('savedQuery', (newSavedQuery, oldSavedQuery) => {
+    if (!newSavedQuery) return;
+    $state.savedQuery = newSavedQuery.id;
+    $state.save();
+
+    if (newSavedQuery.id === (oldSavedQuery && oldSavedQuery.id)) {
+      updateStateFromSavedQuery(newSavedQuery);
+    }
+  });
+
+  $scope.$watch('state.savedQuery', newSavedQueryId => {
+    if (!newSavedQueryId) {
+      $scope.savedQuery = undefined;
+      return;
+    }
+
+    savedQueryService.getSavedQuery(newSavedQueryId).then((savedQuery) => {
+      $scope.$evalAsync(() => {
+        $scope.savedQuery = savedQuery;
+        updateStateFromSavedQuery(savedQuery);
+      });
+    });
+  });
+
   /**
    * Called when the user clicks "Save" button.
    */
