@@ -21,10 +21,10 @@ import PropTypes from 'prop-types';
 import React from 'react';
 import { get, find } from 'lodash';
 import { GroupBySelect } from './group_by_select';
-import createTextHandler from '../lib/create_text_handler';
-import createSelectHandler from '../lib/create_select_handler';
-import FieldSelect from '../aggs/field_select';
-import MetricSelect from '../aggs/metric_select';
+import { createTextHandler } from '../lib/create_text_handler';
+import { createSelectHandler } from '../lib/create_select_handler';
+import { FieldSelect } from '../aggs/field_select';
+import { MetricSelect } from '../aggs/metric_select';
 import {
   htmlIdGenerator,
   EuiFlexGroup,
@@ -32,14 +32,21 @@ import {
   EuiFormRow,
   EuiFieldNumber,
   EuiComboBox,
-  EuiFieldText
+  EuiFieldText,
 } from '@elastic/eui';
 import { injectI18n, FormattedMessage } from '@kbn/i18n/react';
 import { FIELD_TYPES } from '../../../common/field_types';
 
 const DEFAULTS = { terms_direction: 'desc', terms_size: 10, terms_order_by: '_count' };
 
-export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesModel, fields, uiRestrictions }) => {
+export const SplitByTermsUI = ({
+  onChange,
+  indexPattern,
+  intl,
+  model: seriesModel,
+  fields,
+  uiRestrictions,
+}) => {
   const htmlId = htmlIdGenerator();
   const handleTextChange = createTextHandler(onChange);
   const handleSelectChange = createSelectHandler(onChange);
@@ -47,21 +54,30 @@ export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesMode
   const { metrics } = model;
   const defaultCount = {
     value: '_count',
-    label: intl.formatMessage({ id: 'tsvb.splits.terms.defaultCountLabel', defaultMessage: 'Doc Count (default)' })
+    label: intl.formatMessage({
+      id: 'tsvb.splits.terms.defaultCountLabel',
+      defaultMessage: 'Doc Count (default)',
+    }),
   };
   const terms = {
     value: '_key',
-    label: intl.formatMessage({ id: 'tsvb.splits.terms.termsLabel', defaultMessage: 'Terms' })
+    label: intl.formatMessage({ id: 'tsvb.splits.terms.termsLabel', defaultMessage: 'Terms' }),
   };
 
   const dirOptions = [
     {
       value: 'desc',
-      label: intl.formatMessage({ id: 'tsvb.splits.terms.dirOptions.descendingLabel', defaultMessage: 'Descending' })
+      label: intl.formatMessage({
+        id: 'tsvb.splits.terms.dirOptions.descendingLabel',
+        defaultMessage: 'Descending',
+      }),
     },
     {
       value: 'asc',
-      label: intl.formatMessage({ id: 'tsvb.splits.terms.dirOptions.ascendingLabel', defaultMessage: 'Ascending' })
+      label: intl.formatMessage({
+        id: 'tsvb.splits.terms.dirOptions.ascendingLabel',
+        defaultMessage: 'Ascending',
+      }),
     },
   ];
   const selectedDirectionOption = dirOptions.find(option => {
@@ -76,10 +92,9 @@ export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesMode
         <EuiFlexItem>
           <EuiFormRow
             id={htmlId('group')}
-            label={(<FormattedMessage
-              id="tsvb.splits.terms.groupByLabel"
-              defaultMessage="Group by"
-            />)}
+            label={
+              <FormattedMessage id="tsvb.splits.terms.groupByLabel" defaultMessage="Group by" />
+            }
           >
             <GroupBySelect
               value={model.split_mode}
@@ -91,11 +106,13 @@ export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesMode
         <EuiFlexItem>
           <EuiFormRow
             id={htmlId('by')}
-            label={(<FormattedMessage
-              id="tsvb.splits.terms.byLabel"
-              defaultMessage="By"
-              description="This labels a field selector allowing the user to chose 'by' which field to group."
-            />)}
+            label={
+              <FormattedMessage
+                id="tsvb.splits.terms.byLabel"
+                defaultMessage="By"
+                description="This labels a field selector allowing the user to chose 'by' which field to group."
+              />
+            }
           >
             <FieldSelect
               indexPattern={indexPattern}
@@ -114,23 +131,27 @@ export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesMode
           <EuiFlexItem>
             <EuiFormRow
               id={htmlId('include')}
-              label={(<FormattedMessage
-                id="tsvb.splits.terms.includeLabel"
-                defaultMessage="Include"
-              />)}
+              label={
+                <FormattedMessage id="tsvb.splits.terms.includeLabel" defaultMessage="Include" />
+              }
             >
-              <EuiFieldText value={model.terms_include} onChange={handleTextChange('terms_include')} />
+              <EuiFieldText
+                value={model.terms_include}
+                onChange={handleTextChange('terms_include')}
+              />
             </EuiFormRow>
           </EuiFlexItem>
           <EuiFlexItem>
             <EuiFormRow
               id={htmlId('exclude')}
-              label={(<FormattedMessage
-                id="tsvb.splits.terms.excludeLabel"
-                defaultMessage="Exclude"
-              />)}
+              label={
+                <FormattedMessage id="tsvb.splits.terms.excludeLabel" defaultMessage="Exclude" />
+              }
             >
-              <EuiFieldText value={model.terms_exclude} onChange={handleTextChange('terms_exclude')} />
+              <EuiFieldText
+                value={model.terms_exclude}
+                onChange={handleTextChange('terms_exclude')}
+              />
             </EuiFormRow>
           </EuiFlexItem>
         </EuiFlexGroup>
@@ -140,13 +161,13 @@ export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesMode
         <EuiFlexItem>
           <EuiFormRow
             id={htmlId('top')}
-            label={(<FormattedMessage
-              id="tsvb.splits.terms.topLabel"
-              defaultMessage="Top"
-            />)}
+            label={<FormattedMessage id="tsvb.splits.terms.topLabel" defaultMessage="Top" />}
           >
             <EuiFieldNumber
-              placeholder={intl.formatMessage({ id: 'tsvb.splits.terms.sizePlaceholder', defaultMessage: 'Size' })}
+              placeholder={intl.formatMessage({
+                id: 'tsvb.splits.terms.sizePlaceholder',
+                defaultMessage: 'Size',
+              })}
               value={Number(model.terms_size)}
               onChange={handleTextChange('terms_size')}
             />
@@ -155,10 +176,9 @@ export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesMode
         <EuiFlexItem>
           <EuiFormRow
             id={htmlId('order')}
-            label={(<FormattedMessage
-              id="tsvb.splits.terms.orderByLabel"
-              defaultMessage="Order by"
-            />)}
+            label={
+              <FormattedMessage id="tsvb.splits.terms.orderByLabel" defaultMessage="Order by" />
+            }
           >
             <MetricSelect
               metrics={metrics}
@@ -173,10 +193,9 @@ export const SplitByTermsUI = ({ onChange, indexPattern, intl, model: seriesMode
         <EuiFlexItem>
           <EuiFormRow
             id={htmlId('direction')}
-            label={(<FormattedMessage
-              id="tsvb.splits.terms.directionLabel"
-              defaultMessage="Direction"
-            />)}
+            label={
+              <FormattedMessage id="tsvb.splits.terms.directionLabel" defaultMessage="Direction" />
+            }
           >
             <EuiComboBox
               isClearable={false}
