@@ -40,11 +40,9 @@ import {
   EuiTitle,
 } from '@elastic/eui';
 import { FormattedMessage, injectI18n } from '@kbn/i18n/react';
-import { data } from 'plugins/data/setup';
-import { Storage } from 'ui/storage';
 import { getDefaultQueryLanguage } from '../../lib/get_default_query_language';
-const { QueryBarInput } = data.query.ui;
-const localStorage = new Storage(window.localStorage);
+
+import { QueryBarWrapper } from '../../query_bar_wrapper';
 class TableSeriesConfigUI extends Component {
   componentWillMount() {
     const { model } = this.props;
@@ -159,7 +157,7 @@ class TableSeriesConfigUI extends Component {
               label={<FormattedMessage id="tsvb.table.filterLabel" defaultMessage="Filter" />}
               fullWidth
             >
-              <QueryBarInput
+              <QueryBarWrapper
                 query={{
                   language:
                     model.filter && model.filter.language
@@ -168,9 +166,7 @@ class TableSeriesConfigUI extends Component {
                   query: model.filter && model.filter.query ? model.filter.query : '',
                 }}
                 onChange={filter => this.props.onChange({ filter })}
-                appName={'VisEditor'}
                 indexPatterns={[this.props.indexPatternForQuery]}
-                store={localStorage}
               />
             </EuiFormRow>
           </EuiFlexItem>
