@@ -24,7 +24,7 @@ import { EuiRadio, htmlIdGenerator } from '@elastic/eui';
 import { FormattedMessage } from '@kbn/i18n/react';
 
 export function YesNo(props) {
-  const { name, value } = props;
+  const { name, value, disabled } = props;
   const handleChange = value => {
     const { name } = props;
     return () => {
@@ -50,6 +50,7 @@ export function YesNo(props) {
         checked={Boolean(value)}
         value="yes"
         onChange={handleChange(1)}
+        disabled={disabled}
       />
       &emsp;
       <EuiRadio
@@ -66,6 +67,7 @@ export function YesNo(props) {
         checked={!Boolean(value)}
         value="no"
         onChange={handleChange(0)}
+        disabled={disabled}
       />
     </div>
   );
@@ -75,3 +77,7 @@ YesNo.propTypes = {
   name: PropTypes.string,
   value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
 };
+
+YesNo.defaultProps = {
+  disabled: false,
+};
