@@ -22,14 +22,13 @@ import PropTypes from 'prop-types';
 import React, { Component } from 'react';
 import classNames from 'classnames';
 import { isBackgroundInverted, isBackgroundDark } from '../../../common/set_is_reversed';
-import getLastValue from '../../../common/get_last_value';
-import getValueBy from '../lib/get_value_by';
-import GaugeVis from './gauge_vis';
+import { getLastValue } from '../../../common/get_last_value';
+import { getValueBy } from '../lib/get_value_by';
+import { GaugeVis } from './gauge_vis';
 import reactcss from 'reactcss';
-import calculateCoordinates from '../lib/calculate_coordinates';
-
-class Gauge extends Component {
+import { calculateCoordinates } from '../lib/calculate_coordinates';
 
+export class Gauge extends Component {
   constructor(props) {
     super(props);
     this.state = {
@@ -37,7 +36,7 @@ class Gauge extends Component {
       top: 0,
       left: 0,
       translateX: 1,
-      translateY: 1
+      translateY: 1,
     };
 
     this.handleResize = this.handleResize.bind(this);
@@ -72,30 +71,31 @@ class Gauge extends Component {
 
   render() {
     const { metric, type } = this.props;
-    const {
-      scale,
-      translateX,
-      translateY
-    } = this.state;
-    const value = metric && getLastValue(metric.data) || 0;
-    const max = metric && getValueBy('max', metric.data) || 1;
-    const formatter = (metric && (metric.tickFormatter || metric.formatter)) ||
-      this.props.tickFormatter || ((v) => v);
-    const title = metric && metric.label || '';
-    const styles = reactcss({
-      default: {
-        inner: {
-          top: this.state.top || 0,
-          left: this.state.left || 0,
-          transform: `matrix(${scale}, 0, 0, ${scale}, ${translateX}, ${translateY})`
-        }
+    const { scale, translateX, translateY } = this.state;
+    const value = (metric && getLastValue(metric.data)) || 0;
+    const max = (metric && getValueBy('max', metric.data)) || 1;
+    const formatter =
+      (metric && (metric.tickFormatter || metric.formatter)) ||
+      this.props.tickFormatter ||
+      (v => v);
+    const title = (metric && metric.label) || '';
+    const styles = reactcss(
+      {
+        default: {
+          inner: {
+            top: this.state.top || 0,
+            left: this.state.left || 0,
+            transform: `matrix(${scale}, 0, 0, ${scale}, ${translateX}, ${translateY})`,
+          },
+        },
+        valueColor: {
+          value: {
+            color: this.props.valueColor,
+          },
+        },
       },
-      valueColor: {
-        value: {
-          color: this.props.valueColor
-        }
-      }
-    }, this.props);
+      this.props
+    );
 
     const gaugeProps = {
       value,
@@ -104,36 +104,29 @@ class Gauge extends Component {
       innerLine: this.props.innerLine,
       innerColor: this.props.innerColor,
       max: this.props.max || max,
-      color: metric && metric.color || '#8ac336',
-      type
+      color: (metric && metric.color) || '#8ac336',
+      type,
     };
 
     let metrics;
     let additionalLabel;
     if (this.props.additionalLabel) {
       additionalLabel = (
-        <div className="tvbVisGauge__additionalLabel">
-          {this.props.additionalLabel}
-        </div>
+        <div className="tvbVisGauge__additionalLabel">{this.props.additionalLabel}</div>
       );
     }
     if (type === 'half') {
       metrics = (
         <div
           className="tvbVisHalfGauge__metrics"
-          ref={(el) => this.inner = el}
+          ref={el => (this.inner = el)}
           style={styles.inner}
         >
-          <div
-            className="tvbVisGauge__label"
-            ref="title"
-          >{ title }
+          <div className="tvbVisGauge__label" ref="title">
+            {title}
           </div>
-          <div
-            className="tvbVisGauge__value"
-            style={styles.value}
-            ref="label"
-          >{ formatter(value) }
+          <div className="tvbVisGauge__value" style={styles.value} ref="label">
+            {formatter(value)}
           </div>
           {additionalLabel}
         </div>
@@ -142,19 +135,14 @@ class Gauge extends Component {
       metrics = (
         <div
           className="tvbVisCircleGauge__metrics"
-          ref={(el) => this.inner = el}
+          ref={el => (this.inner = el)}
           style={styles.inner}
         >
-          <div
-            className="tvbVisGauge__value"
-            style={styles.value}
-            ref="label"
-          >{ formatter(value) }
+          <div className="tvbVisGauge__value" style={styles.value} ref="label">
+            {formatter(value)}
           </div>
-          <div
-            className="tvbVisGauge__label"
-            ref="title"
-          >{ title }
+          <div className="tvbVisGauge__label" ref="title">
+            {title}
           </div>
           {additionalLabel}
         </div>
@@ -162,31 +150,30 @@ class Gauge extends Component {
     }
 
     const classes = classNames({
-      'tvbVisHalfGauge': type === 'half',
-      'tvbVisCircleGauge': type === 'circle',
+      tvbVisHalfGauge: type === 'half',
+      tvbVisCircleGauge: type === 'circle',
       'tvbVisGauge--reversed': isBackgroundInverted(this.props.backgroundColor),
     });
 
     return (
       <div className={classes}>
         <div
-          ref={(el) => this.resize = el}
+          ref={el => (this.resize = el)}
           className={`tvbVisGauge__resize`}
           data-test-subj="tvbVisGaugeContainer"
         >
-          { metrics }
-          <GaugeVis {...gaugeProps}/>
+          {metrics}
+          <GaugeVis {...gaugeProps} />
         </div>
       </div>
     );
   }
-
 }
 
 Gauge.defaultProps = {
   type: 'half',
   innerLine: 2,
-  gaugeLine: 10
+  gaugeLine: 10,
 };
 
 Gauge.propTypes = {
@@ -198,8 +185,5 @@ Gauge.propTypes = {
   backgroundColor: PropTypes.string,
   type: PropTypes.oneOf(['half', 'circle']),
   valueColor: PropTypes.string,
-  additionalLabel: PropTypes.string
+  additionalLabel: PropTypes.string,
 };
-
-export default Gauge;
-
