@@ -19,16 +19,16 @@
 
 import PropTypes from 'prop-types';
 import React, { Component } from 'react';
-import getLastValue from '../../../common/get_last_value';
+import { getLastValue } from '../../../common/get_last_value';
 import reactcss from 'reactcss';
 
-class TopN extends Component {
+export class TopN extends Component {
   constructor(props) {
     super(props);
 
     this.tableRef = React.createRef();
     this.state = {
-      labelMaxWidth: 150
+      labelMaxWidth: 150,
     };
   }
 
@@ -39,14 +39,14 @@ class TopN extends Component {
 
   componentDidMount() {
     this.setState({
-      labelMaxWidth: this.labelMaxWidth
+      labelMaxWidth: this.labelMaxWidth,
     });
   }
 
   componentDidUpdate(prevProps, prevState) {
     if (prevState.labelMaxWidth !== this.labelMaxWidth) {
       this.setState({
-        labelMaxWidth: this.labelMaxWidth
+        labelMaxWidth: this.labelMaxWidth,
       });
     }
   }
@@ -67,38 +67,36 @@ class TopN extends Component {
       const value = formatter(lastValue);
       const width = `${100 * (lastValue / maxValue)}%`;
       const backgroundColor = item.color;
-      const styles = reactcss({
-        default: {
-          innerBar: {
-            width,
-            backgroundColor
+      const styles = reactcss(
+        {
+          default: {
+            innerBar: {
+              width,
+              backgroundColor,
+            },
+            label: {
+              maxWidth: this.state.labelMaxWidth,
+            },
+          },
+          onClick: {
+            row: {
+              cursor: 'pointer',
+            },
           },
-          label: {
-            maxWidth: this.state.labelMaxWidth
-          }
         },
-        onClick: {
-          row: {
-            cursor: 'pointer'
-          }
-        }
-      }, this.props);
+        this.props
+      );
       return (
-        <tr
-          key={key}
-          onClick={this.handleClick({ lastValue, ...item })}
-          style={styles.row}
-        >
+        <tr key={key} onClick={this.handleClick({ lastValue, ...item })} style={styles.row}>
           <td title={item.label} className="tvbVisTopN__label" style={styles.label}>
-            { item.label }
+            {item.label}
           </td>
           <td width="100%" className="tvbVisTopN__bar">
-            <div
-              className="tvbVisTopN__innerBar"
-              style={styles.innerBar}
-            />
+            <div className="tvbVisTopN__innerBar" style={styles.innerBar} />
+          </td>
+          <td className="tvbVisTopN__value" data-test-subj="tsvbTopNValue">
+            {value}
           </td>
-          <td className="tvbVisTopN__value" data-test-subj="tsvbTopNValue">{ value }</td>
         </tr>
       );
     };
@@ -120,20 +118,17 @@ class TopN extends Component {
     return (
       <div className={className}>
         <table className="tvbVisTopN__table" data-test-subj="tvbVisTopNTable" ref={this.tableRef}>
-          <tbody>
-            { rows }
-          </tbody>
+          <tbody>{rows}</tbody>
         </table>
       </div>
     );
   }
-
 }
 
 TopN.defaultProps = {
   tickFormatter: n => n,
   onClick: i => i,
-  direction: 'desc'
+  direction: 'desc',
 };
 
 TopN.propTypes = {
@@ -141,7 +136,5 @@ TopN.propTypes = {
   onClick: PropTypes.func,
   series: PropTypes.array,
   reversed: PropTypes.bool,
-  direction: PropTypes.string
+  direction: PropTypes.string,
 };
-
-export default TopN;
