@@ -17,20 +17,20 @@
  * under the License.
  */
 
-import 'plugins/kbn_vislib_vis_types/controls/vislib_basic_options';
 import { i18n } from '@kbn/i18n';
-import { BaseMapsVisualizationProvider } from '../../tile_map/public/base_maps_visualization';
 import ChoroplethLayer from './choropleth_layer';
 import { truncatedColorMaps }  from 'ui/vislib/components/color/truncated_colormaps';
 import { getFormat } from 'ui/visualize/loader/pipeline_helpers/utilities';
-import { TileMapTooltipFormatter } from './tooltip_formatter';
-import 'ui/vis/map/service_settings';
 import { toastNotifications } from 'ui/notify';
 
-export function RegionMapsVisualizationProvider(Private, config) {
+import { TileMapTooltipFormatter } from './tooltip_formatter';
 
-  const tooltipFormatter = Private(TileMapTooltipFormatter);
-  const BaseMapsVisualization = Private(BaseMapsVisualizationProvider);
+// TODO: reference to TILE_MAP plugin should be removed
+import { BaseMapsVisualizationProvider } from '../../tile_map/public/base_maps_visualization';
+
+export function createRegionMapVisualization({ serviceSettings, $injector, uiSettings }) {
+  const BaseMapsVisualization = new BaseMapsVisualizationProvider(serviceSettings);
+  const tooltipFormatter = new TileMapTooltipFormatter($injector);
 
   return class RegionMapsVisualization extends BaseMapsVisualization {
 
@@ -141,7 +141,8 @@ export function RegionMapsVisualizationProvider(Private, config) {
           this._params.selectedLayer.format,
           showAllData,
           this._params.selectedLayer.meta,
-          this._params.selectedLayer
+          this._params.selectedLayer,
+          serviceSettings
         );
       } else {
         this._choroplethLayer = new ChoroplethLayer(
@@ -150,7 +151,8 @@ export function RegionMapsVisualizationProvider(Private, config) {
           this._params.selectedLayer.format,
           showAllData,
           this._params.selectedLayer.meta,
-          this._params.selectedLayer
+          this._params.selectedLayer,
+          serviceSettings,
         );
       }
 
@@ -160,7 +162,7 @@ export function RegionMapsVisualizationProvider(Private, config) {
       });
 
       this._choroplethLayer.on('styleChanged', (event) => {
-        const shouldShowWarning = this._params.isDisplayWarning && config.get('visualization:regionmap:showWarnings');
+        const shouldShowWarning = this._params.isDisplayWarning && uiSettings.get('visualization:regionmap:showWarnings');
         if (event.mismatches.length > 0 && shouldShowWarning) {
           toastNotifications.addWarning({
             title: i18n.translate('regionMap.visualization.unableToShowMismatchesWarningTitle', {
