@@ -22,14 +22,16 @@ import { i18n } from '@kbn/i18n';
 
 import template from './_tooltip.html';
 
-export function TileMapTooltipFormatterProvider($compile, $rootScope) {
+export function TileMapTooltipFormatterProvider($injector) {
+  const $rootScope = $injector.get('$rootScope');
+  const $compile = $injector.get('$compile');
 
   const $tooltipScope = $rootScope.$new();
   const $el = $('<div>').html(template);
+
   $compile($el)($tooltipScope);
 
   return function tooltipFormatter(aggConfig, metricAgg, feature) {
-
     if (!feature) {
       return '';
     }
