@@ -24,7 +24,7 @@ import { i18n } from '@kbn/i18n';
 import { capabilities } from 'ui/capabilities';
 import { docTitle } from 'ui/doc_title';
 import { SavedObjectRegistryProvider } from 'ui/saved_objects/saved_object_registry';
-import { notify, fatalError, toastNotifications } from 'ui/notify';
+import { fatalError, toastNotifications } from 'ui/notify';
 import { timezoneProvider } from 'ui/vis/lib/timezone';
 import { recentlyAccessed } from 'ui/persisted_log';
 import { timefilter } from 'ui/timefilter';
@@ -39,7 +39,7 @@ require('ui/autoload/all');
 // TODO: remove ui imports completely (move to plugins)
 import 'ui/directives/input_focus';
 import 'ui/directives/saved_object_finder';
-import 'ui/listen';
+import 'ui/directives/listen';
 import 'ui/kbn_top_nav';
 import 'ui/saved_objects/ui/saved_object_save_as_checkbox';
 
@@ -66,8 +66,6 @@ require('./vis');
 
 SavedObjectRegistryProvider.register(require('plugins/timelion/services/saved_sheet_register'));
 
-const unsafeNotifications = notify._notifs;
-
 require('ui/routes').enable();
 
 require('ui/routes')
@@ -146,7 +144,7 @@ app.controller('timelion', function (
 
   $timeout(function () {
     if (config.get('timelion:showTutorial', true)) {
-      $scope.menus.showHelp = true;
+      $scope.toggleMenu('showHelp');
     }
   }, 0);
 
@@ -165,7 +163,7 @@ app.controller('timelion', function (
   function getTopNavMenu() {
 
     const newSheetAction = {
-      key: 'new',
+      id: 'new',
       label: i18n.translate('timelion.topNavMenu.newSheetButtonLabel', {
         defaultMessage: 'New',
       }),
@@ -177,19 +175,21 @@ app.controller('timelion', function (
     };
 
     const addSheetAction = {
-      key: 'add',
+      id: 'add',
       label: i18n.translate('timelion.topNavMenu.addChartButtonLabel', {
         defaultMessage: 'Add',
       }),
       description: i18n.translate('timelion.topNavMenu.addChartButtonAriaLabel', {
         defaultMessage: 'Add a chart',
       }),
-      run: function () { $scope.newCell(); },
+      run: function () {
+        $scope.$evalAsync(() => $scope.newCell());
+      },
       testId: 'timelionAddChartButton',
     };
 
     const saveSheetAction = {
-      key: 'save',
+      id: 'save',
       label: i18n.translate('timelion.topNavMenu.saveSheetButtonLabel', {
         defaultMessage: 'Save',
       }),
@@ -197,15 +197,13 @@ app.controller('timelion', function (
         defaultMessage: 'Save Sheet',
       }),
       run: () => {
-        const curState = $scope.menus.showSave;
-        $scope.closeMenus();
-        $scope.menus.showSave = !curState;
+        $scope.$evalAsync(() => $scope.toggleMenu('showSave'));
       },
       testId: 'timelionSaveButton',
     };
 
     const deleteSheetAction = {
-      key: 'delete',
+      id: 'delete',
       label: i18n.translate('timelion.topNavMenu.deleteSheetButtonLabel', {
         defaultMessage: 'Delete',
       }),
@@ -241,18 +239,21 @@ app.controller('timelion', function (
           }),
         };
 
-        confirmModal(
-          i18n.translate('timelion.topNavMenu.delete.modal.warningText', {
-            defaultMessage: `You can't recover deleted sheets.`,
-          }),
-          confirmModalOptions
-        );
+        $scope.$evalAsync(() => {
+          confirmModal(
+            i18n.translate('timelion.topNavMenu.delete.modal.warningText', {
+              defaultMessage: `You can't recover deleted sheets.`,
+            }),
+            confirmModalOptions
+          );
+        });
+
       },
       testId: 'timelionDeleteButton',
     };
 
     const openSheetAction = {
-      key: 'open',
+      id: 'open',
       label: i18n.translate('timelion.topNavMenu.openSheetButtonLabel', {
         defaultMessage: 'Open',
       }),
@@ -260,15 +261,13 @@ app.controller('timelion', function (
         defaultMessage: 'Open Sheet',
       }),
       run: () => {
-        const curState = $scope.menus.showLoad;
-        $scope.closeMenus();
-        $scope.menus.showLoad = !curState;
+        $scope.$evalAsync(() => $scope.toggleMenu('showLoad'));
       },
       testId: 'timelionOpenButton',
     };
 
     const optionsAction = {
-      key: 'options',
+      id: 'options',
       label: i18n.translate('timelion.topNavMenu.optionsButtonLabel', {
         defaultMessage: 'Options',
       }),
@@ -276,15 +275,13 @@ app.controller('timelion', function (
         defaultMessage: 'Options',
       }),
       run: () => {
-        const curState = $scope.menus.showOptions;
-        $scope.closeMenus();
-        $scope.menus.showOptions = !curState;
+        $scope.$evalAsync(() => $scope.toggleMenu('showOptions'));
       },
       testId: 'timelionOptionsButton',
     };
 
     const helpAction = {
-      key: 'help',
+      id: 'help',
       label: i18n.translate('timelion.topNavMenu.helpButtonLabel', {
         defaultMessage: 'Help',
       }),
@@ -292,9 +289,7 @@ app.controller('timelion', function (
         defaultMessage: 'Help',
       }),
       run: () => {
-        const curState = $scope.menus.showHelp;
-        $scope.closeMenus();
-        $scope.menus.showHelp = !curState;
+        $scope.$evalAsync(() => $scope.toggleMenu('showHelp'));
       },
       testId: 'timelionDocsButton',
     };
@@ -305,42 +300,8 @@ app.controller('timelion', function (
     return [newSheetAction, addSheetAction, openSheetAction, optionsAction, helpAction];
   }
 
-  const init = function () {
-    $scope.running = false;
-    $scope.search();
-
-    $scope.$listen($scope.state, 'fetch_with_changes', $scope.search);
-    $scope.$listen(timefilter, 'fetch', $scope.search);
-
-    $scope.opts = {
-      saveExpression: saveExpression,
-      saveSheet: saveSheet,
-      savedSheet: savedSheet,
-      state: $scope.state,
-      search: $scope.search,
-      dontShowHelp: function () {
-        config.set('timelion:showTutorial', false);
-        $scope.setPage(0);
-        $scope.menus.showHelp = false;
-      }
-    };
-
-    $scope.menus = {
-      showHelp: false,
-      showSave: false,
-      showLoad: false,
-      showOptions: false,
-    };
-
-    $scope.closeMenus = () => {
-      _.forOwn($scope.menus, function (value, key) {
-        $scope.menus[key] = false;
-      });
-    };
-  };
-
   let refresher;
-  $scope.$listen(timefilter, 'refreshIntervalUpdate', function () {
+  const setRefreshData = function () {
     if (refresher) $timeout.cancel(refresher);
     const interval = timefilter.getRefreshInterval();
     if (interval.value > 0 && !interval.pause) {
@@ -352,7 +313,73 @@ app.controller('timelion', function (
       }
       startRefresh();
     }
-  });
+  };
+
+  const init = function () {
+    $scope.running = false;
+    $scope.search();
+    setRefreshData();
+
+    $scope.model = {
+      timeRange: timefilter.getTime(),
+      refreshInterval: timefilter.getRefreshInterval(),
+    };
+
+    $scope.$listen($scope.state, 'fetch_with_changes', $scope.search);
+    timefilter.getFetch$().subscribe($scope.search);
+
+    $scope.opts = {
+      saveExpression: saveExpression,
+      saveSheet: saveSheet,
+      savedSheet: savedSheet,
+      state: $scope.state,
+      search: $scope.search,
+      dontShowHelp: function () {
+        config.set('timelion:showTutorial', false);
+        $scope.setPage(0);
+        $scope.closeMenus();
+      }
+    };
+
+    $scope.menus = {
+      showHelp: false,
+      showSave: false,
+      showLoad: false,
+      showOptions: false,
+    };
+
+    $scope.toggleMenu = (menuName) => {
+      const curState = $scope.menus[menuName];
+      $scope.closeMenus();
+      $scope.menus[menuName] = !curState;
+    };
+
+    $scope.closeMenus = () => {
+      _.forOwn($scope.menus, function (value, key) {
+        $scope.menus[key] = false;
+      });
+    };
+  };
+
+  $scope.onTimeUpdate = function ({ dateRange }) {
+    $scope.model.timeRange = {
+      ...dateRange
+    };
+    timefilter.setTime(dateRange);
+  };
+
+  $scope.onRefreshChange = function ({ isPaused, refreshInterval }) {
+    $scope.model.refreshInterval = {
+      pause: isPaused,
+      value: refreshInterval,
+    };
+    timefilter.setRefreshInterval({
+      pause: isPaused,
+      value: refreshInterval ? refreshInterval : $scope.refreshInterval.value
+    });
+
+    setRefreshData();
+  };
 
   $scope.$watch(function () { return savedSheet.lastSavedTitle; }, function (newTitle) {
     docTitle.change(savedSheet.id ? newTitle : undefined);
@@ -392,7 +419,6 @@ app.controller('timelion', function (
 
     httpResult
       .then(function (resp) {
-        dismissNotifications();
         $scope.stats = resp.stats;
         $scope.sheet = resp.sheet;
         _.each(resp.sheet, function (cell) {
@@ -461,9 +487,5 @@ app.controller('timelion', function (
     });
   }
 
-  function dismissNotifications() {
-    unsafeNotifications.splice(0, unsafeNotifications.length);
-  }
-
   init();
 });
