@@ -21,7 +21,7 @@ import React from 'react';
 
 const wrapWithInlineComp = Component => props => (
   <div className={`visEditorAggParam--half visEditorAggParam--half-${props.aggParam.name}`}>
-    <Component {...props} wrappedWithInlineComp={true}/>
+    <Component {...props}/>
   </div>);
 
 export { wrapWithInlineComp };
