@@ -26,6 +26,7 @@ import { PrecisionParamEditor } from '../controls/precision';
 import { geohashColumns } from '../../utils/decode_geo_hash';
 import { geoContains, scaleBounds } from '../../utils/geo_utils';
 import { i18n } from '@kbn/i18n';
+import { AggGroupNames } from '../../vis/editors/default/agg_groups';
 
 const config = chrome.getUiSettingsClient();
 
@@ -156,7 +157,7 @@ export const geoHashBucketAgg = new BucketAggType({
             geo_bounding_box: boundingBox
           },
           schema: {
-            group: 'buckets'
+            group: AggGroupNames.Buckets
           }
         },  { addToAggConfigs: false }));
       }
