@@ -20,13 +20,11 @@
 import { sortBy } from 'lodash';
 import { SavedObjectNotFound } from '../../errors';
 import { FieldParamEditor } from '../controls/field';
-import '../directives/scroll_bottom';
 import { BaseParamType } from './base';
-import '../filters/sort_prefix_first';
 import { IndexedArray } from '../../indexed_array';
 import { toastNotifications } from '../../notify';
 import { createLegacyClass } from '../../utils/legacy_class';
-import { propFilter } from '../../filters/_prop_filter';
+import { propFilter } from '../filter';
 import { i18n } from '@kbn/i18n';
 
 const filterByType = propFilter('type');
