@@ -17,11 +17,8 @@
  * under the License.
  */
 
-import 'plugins/kbn_vislib_vis_types/controls/vislib_basic_options';
-import 'plugins/kbn_vislib_vis_types/controls/point_series_options';
 import 'plugins/kbn_vislib_vis_types/controls/line_interpolation_option';
 import 'plugins/kbn_vislib_vis_types/controls/heatmap_options';
-import 'plugins/kbn_vislib_vis_types/controls/gauge_options';
 import 'plugins/kbn_vislib_vis_types/controls/point_series';
 import { CUSTOM_LEGEND_VIS_TYPES } from './vislib_vis_legend';
 import { BaseVisType } from './base_vis_type';
