@@ -252,6 +252,9 @@ export class AreaChart extends PointSeries {
         const circles = self.addCircles(svg, self.chartData);
         self.addCircleEvents(circles);
 
+        if (self.thresholdLineOptions.show) {
+          self.addThresholdLine(self.chartEl);
+        }
         self.events.emit('rendered', {
           chart: self.chartData
         });
