@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,11 +18,8 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 require('jquery');
+
 require('../node_modules/angular/angular');
-module.exports = window.angular;
 
-require('../node_modules/angular-elastic/elastic');
-
-require('ui/modules').get('kibana', ['monospaced.elastic']);
\ No newline at end of file
+module.exports = window.angular;
\ No newline at end of file
