@@ -18,4 +18,4 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-module.exports = require('../node_modules/moment/min/moment.min.js');
\ No newline at end of file
+module.exports = require('../node_modules/moment/min/moment-with-locales.min.js');
\ No newline at end of file
